@@ -118,14 +118,6 @@ struct _PhotosApplication
   gulong source_removed_id;
 };
 
-struct _PhotosApplicationClass
-{
-  GtkApplicationClass parent_class;
-
-  /* signals */
-  void (*miners_changed) (PhotosApplication *self, GList *miners_running);
-};
-
 enum
 {
   MINERS_CHANGED,
@@ -160,14 +152,13 @@ static const gchar *REQUIRED_GEGL_OPS[] =
   "gegl:crop",
   "gegl:gray",
   "gegl:load",
-  "gegl:noise-reduction",
   "gegl:nop",
   "gegl:rotate-on-center",
   "gegl:save-pixbuf",
   "gegl:scale-ratio",
-  "gegl:unsharp-mask",
 
   /* Used by gegl:load */
+  "gegl:jp2-load",
   "gegl:jpg-load",
   "gegl:png-load",
   "gegl:raw-load",
@@ -1635,7 +1626,6 @@ photos_application_startup (GApplication *application)
   const gchar *edit_accels[2] = {"<Primary>e", NULL};
   const gchar *fullscreen_accels[2] = {"F11", NULL};
   const gchar *gear_menu_accels[2] = {"F10", NULL};
-  const gchar *help_menu_accels[2] = {"F1", NULL};
   const gchar *print_current_accels[2] = {"<Primary>p", NULL};
   const gchar *quit_accels[2] = {"<Primary>q", NULL};
   const gchar *save_accels[2] = {"<Primary>x", NULL};
@@ -1859,7 +1849,6 @@ photos_application_startup (GApplication *application)
   gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.edit-current", edit_accels);
   gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.fullscreen", fullscreen_accels);
   gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.gear-menu", gear_menu_accels);
-  gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.help", help_menu_accels);
   gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.print-current", print_current_accels);
   gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.save-current", save_accels);
   gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.search", search_accels);
@@ -2000,13 +1989,12 @@ photos_application_class_init (PhotosApplicationClass *class)
   signals[MINERS_CHANGED] = g_signal_new ("miners-changed",
                                           G_TYPE_FROM_CLASS (class),
                                           G_SIGNAL_RUN_LAST,
-                                          G_STRUCT_OFFSET (PhotosApplicationClass, miners_changed),
+                                          0,
                                           NULL, /* accumulator */
                                           NULL, /* accu_data */
                                           g_cclosure_marshal_VOID__POINTER,
                                           G_TYPE_NONE,
-                                          1,
-                                          G_TYPE_POINTER);
+                                          0);
 }
 
 
