@@ -30,36 +30,10 @@
 G_BEGIN_DECLS
 
 #define PHOTOS_TYPE_BASE_MANAGER (photos_base_manager_get_type ())
+G_DECLARE_DERIVABLE_TYPE (PhotosBaseManager, photos_base_manager, PHOTOS, BASE_MANAGER, GObject);
 
-#define PHOTOS_BASE_MANAGER(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
-   PHOTOS_TYPE_BASE_MANAGER, PhotosBaseManager))
-
-#define PHOTOS_BASE_MANAGER_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST ((klass), \
-   PHOTOS_TYPE_BASE_MANAGER, PhotosBaseManagerClass))
-
-#define PHOTOS_IS_BASE_MANAGER(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
-   PHOTOS_TYPE_BASE_MANAGER))
-
-#define PHOTOS_IS_BASE_MANAGER_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_TYPE ((klass), \
-   PHOTOS_TYPE_BASE_MANAGER))
-
-#define PHOTOS_BASE_MANAGER_GET_CLASS(obj) \
-  (G_TYPE_INSTANCE_GET_CLASS ((obj), \
-   PHOTOS_TYPE_BASE_MANAGER, PhotosBaseManagerClass))
-
-typedef struct _PhotosBaseManager        PhotosBaseManager;
-typedef struct _PhotosBaseManagerClass   PhotosBaseManagerClass;
 typedef struct _PhotosBaseManagerPrivate PhotosBaseManagerPrivate;
 
-struct _PhotosBaseManager
-{
-  GObject parent_instance;
-};
-
 struct _PhotosBaseManagerClass
 {
   GObjectClass parent_class;
@@ -69,7 +43,6 @@ struct _PhotosBaseManagerClass
   GObject       *(*get_active_object)      (PhotosBaseManager *self);
   gchar         *(*get_filter)             (PhotosBaseManager *self, gint flags);
   GObject       *(*get_object_by_id)       (PhotosBaseManager *self, const gchar *id);
-  GHashTable    *(*get_objects)            (PhotosBaseManager *self);
   gchar         *(*get_where)              (PhotosBaseManager *self, gint flags);
   void           (*remove_object_by_id)    (PhotosBaseManager *self, const gchar *id);
   gboolean       (*set_active_object)      (PhotosBaseManager *self, GObject *object);
@@ -81,8 +54,6 @@ struct _PhotosBaseManagerClass
   void           (*object_removed)         (PhotosBaseManager *self, GObject *object);
 };
 
-GType               photos_base_manager_get_type                 (void) G_GNUC_CONST;
-
 PhotosBaseManager  *photos_base_manager_new                      (void);
 
 void                photos_base_manager_add_object               (PhotosBaseManager *self, GObject *object);
@@ -99,8 +70,6 @@ gchar              *photos_base_manager_get_filter               (PhotosBaseMana
 
 GObject            *photos_base_manager_get_object_by_id         (PhotosBaseManager *self, const gchar *id);
 
-GHashTable         *photos_base_manager_get_objects              (PhotosBaseManager *self);
-
 guint               photos_base_manager_get_objects_count        (PhotosBaseManager *self);
 
 const gchar        *photos_base_manager_get_title                (PhotosBaseManager *self);
