@@ -30,7 +30,7 @@
 G_BEGIN_DECLS
 
 #define PHOTOS_TYPE_DROPDOWN (photos_dropdown_get_type ())
-G_DECLARE_FINAL_TYPE (PhotosDropdown, photos_dropdown, PHOTOS, DROPDOWN, GtkPopover)
+G_DECLARE_FINAL_TYPE (PhotosDropdown, photos_dropdown, PHOTOS, DROPDOWN, GtkPopover);
 
 GtkWidget                *photos_dropdown_new                  (void);
 
