@@ -28,31 +28,7 @@
 G_BEGIN_DECLS
 
 #define PHOTOS_TYPE_EXPORT_DIALOG (photos_export_dialog_get_type ())
-
-#define PHOTOS_EXPORT_DIALOG(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
-   PHOTOS_TYPE_EXPORT_DIALOG, PhotosExportDialog))
-
-#define PHOTOS_EXPORT_DIALOG_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST ((klass), \
-   PHOTOS_TYPE_EXPORT_DIALOG, PhotosExportDialogClass))
-
-#define PHOTOS_IS_EXPORT_DIALOG(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
-   PHOTOS_TYPE_EXPORT_DIALOG))
-
-#define PHOTOS_IS_EXPORT_DIALOG_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_TYPE ((klass), \
-   PHOTOS_TYPE_EXPORT_DIALOG))
-
-#define PHOTOS_EXPORT_DIALOG_GET_CLASS(obj) \
-  (G_TYPE_INSTANCE_GET_CLASS ((obj), \
-   PHOTOS_TYPE_EXPORT_DIALOG, PhotosExportDialogClass))
-
-typedef struct _PhotosExportDialog      PhotosExportDialog;
-typedef struct _PhotosExportDialogClass PhotosExportDialogClass;
-
-GType               photos_export_dialog_get_type           (void) G_GNUC_CONST;
+G_DECLARE_FINAL_TYPE (PhotosExportDialog, photos_export_dialog, PHOTOS, EXPORT_DIALOG, GtkDialog);
 
 GtkWidget          *photos_export_dialog_new                (GtkWindow *parent, PhotosBaseItem *item);
 
