@@ -90,8 +90,11 @@ enum
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
+static void photos_item_manager_list_model_iface_init (GListModelInterface *iface);
 
-G_DEFINE_TYPE (PhotosItemManager, photos_item_manager, PHOTOS_TYPE_BASE_MANAGER);
+
+G_DEFINE_TYPE_WITH_CODE (PhotosItemManager, photos_item_manager, PHOTOS_TYPE_BASE_MANAGER,
+                         G_IMPLEMENT_INTERFACE (G_TYPE_LIST_MODEL, photos_item_manager_list_model_iface_init));
 EGG_DEFINE_COUNTER (instances, "PhotosItemManager", "Instances", "Number of PhotosItemManager instances")
 
 
@@ -145,9 +148,6 @@ photos_item_manager_check_wait_for_changes (PhotosItemManager *self, const gchar
   GList *l;
   GList *tasks;
 
-  g_return_if_fail (id != NULL && id[0] != '\0');
-  g_return_if_fail (uri != NULL && uri[0] != '\0');
-
   tasks = (GList *) g_hash_table_lookup (self->wait_for_changes_table, uri);
   for (l = tasks; l != NULL; l = l->next)
     {
@@ -159,18 +159,6 @@ photos_item_manager_check_wait_for_changes (PhotosItemManager *self, const gchar
 }
 
 
-static gboolean
-photos_item_manager_cursor_is_collection (TrackerSparqlCursor *cursor)
-{
-  gboolean ret_val;
-  const gchar *rdf_type;
-
-  rdf_type = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_RDF_TYPE, NULL);
-  ret_val = strstr (rdf_type, "nfo#DataContainer") != NULL;
-  return ret_val;
-}
-
-
 static void
 photos_item_manager_item_created_executed (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
@@ -178,6 +166,8 @@ photos_item_manager_item_created_executed (GObject *source_object, GAsyncResult
   GError *error = NULL;
   PhotosSingleItemJob *job = PHOTOS_SINGLE_ITEM_JOB (source_object);
   TrackerSparqlCursor *cursor = NULL;
+  const gchar *id;
+  const gchar *uri;
 
   cursor = photos_single_item_job_finish (job, res, &error);
   if (error != NULL)
@@ -192,15 +182,9 @@ photos_item_manager_item_created_executed (GObject *source_object, GAsyncResult
 
   photos_item_manager_add_item (self, cursor, FALSE);
 
-  if (!photos_item_manager_cursor_is_collection (cursor))
-    {
-      const gchar *id;
-      const gchar *uri;
-
-      id = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL);
-      uri = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URI, NULL);
-      photos_item_manager_check_wait_for_changes (self, id, uri);
-    }
+  id = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL);
+  uri = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URI, NULL);
+  photos_item_manager_check_wait_for_changes (self, id, uri);
 
  out:
   g_clear_object (&cursor);
@@ -251,15 +235,12 @@ photos_item_manager_changes_pending_foreach (gpointer key, gpointer value, gpoin
       object = photos_base_manager_get_object_by_id (PHOTOS_BASE_MANAGER (self), change_urn);
       if (object != NULL)
         {
+          const gchar *uri;
+
           photos_base_item_refresh (PHOTOS_BASE_ITEM (object));
 
-          if (!photos_base_item_is_collection (PHOTOS_BASE_ITEM (object)))
-	    {
-              const gchar *uri;
-
-              uri = photos_base_item_get_uri (PHOTOS_BASE_ITEM (object));
-              photos_item_manager_check_wait_for_changes (self, change_urn, uri);
-	    }
+          uri = photos_base_item_get_uri (PHOTOS_BASE_ITEM (object));
+          photos_item_manager_check_wait_for_changes (self, change_urn, uri);
         }
     }
   else if (change_type == PHOTOS_TRACKER_CHANGE_EVENT_CREATED)
@@ -314,6 +295,18 @@ photos_item_manager_collection_path_free (PhotosItemManager *self)
 }
 
 
+static gboolean
+photos_item_manager_cursor_is_collection (TrackerSparqlCursor *cursor)
+{
+  gboolean ret_val;
+  const gchar *rdf_type;
+
+  rdf_type = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_RDF_TYPE, NULL);
+  ret_val = strstr (rdf_type, "nfo#DataContainer") != NULL;
+  return ret_val;
+}
+
+
 static gboolean
 photos_item_manager_cursor_is_favorite (TrackerSparqlCursor *cursor)
 {
@@ -337,6 +330,35 @@ photos_item_manager_get_active_object (PhotosBaseManager *mngr)
 }
 
 
+static gpointer
+photos_item_manager_get_item (GListModel *list, guint position)
+{
+  PhotosItemManager *self = PHOTOS_ITEM_MANAGER (list);
+  gpointer item;
+
+  item = g_list_model_get_item (G_LIST_MODEL (self->item_mngr_chldrn[0]), position);
+  return item;
+}
+
+
+static GType
+photos_item_manager_get_item_type (GListModel *list)
+{
+  return PHOTOS_TYPE_BASE_ITEM;
+}
+
+
+static guint
+photos_item_manager_get_n_items (GListModel *list)
+{
+  PhotosItemManager *self = PHOTOS_ITEM_MANAGER (list);
+  guint n_items;
+
+  n_items = g_list_model_get_n_items (G_LIST_MODEL (self->item_mngr_chldrn[0]));
+  return n_items;
+}
+
+
 static GObject *
 photos_item_manager_get_object_by_id (PhotosBaseManager *mngr, const gchar *id)
 {
@@ -348,17 +370,6 @@ photos_item_manager_get_object_by_id (PhotosBaseManager *mngr, const gchar *id)
 }
 
 
-static GHashTable *
-photos_item_manager_get_objects (PhotosBaseManager *mngr)
-{
-  PhotosItemManager *self = PHOTOS_ITEM_MANAGER (mngr);
-  GHashTable *ret_val;
-
-  ret_val = photos_base_manager_get_objects (self->item_mngr_chldrn[0]);
-  return ret_val;
-}
-
-
 static gchar *
 photos_item_manager_get_where (PhotosBaseManager *mngr, gint flags)
 {
@@ -693,7 +704,6 @@ photos_item_manager_class_init (PhotosItemManagerClass *class)
   base_manager_class->get_active_object = photos_item_manager_get_active_object;
   base_manager_class->get_where = photos_item_manager_get_where;
   base_manager_class->get_object_by_id = photos_item_manager_get_object_by_id;
-  base_manager_class->get_objects = photos_item_manager_get_objects;
   base_manager_class->set_active_object = photos_item_manager_set_active_object;
   base_manager_class->remove_object_by_id = photos_item_manager_remove_object_by_id;
 
@@ -772,6 +782,15 @@ photos_item_manager_class_init (PhotosItemManagerClass *class)
 }
 
 
+static void
+photos_item_manager_list_model_iface_init (GListModelInterface *iface)
+{
+  iface->get_item = photos_item_manager_get_item;
+  iface->get_item_type = photos_item_manager_get_item_type;
+  iface->get_n_items = photos_item_manager_get_n_items;
+}
+
+
 PhotosBaseManager *
 photos_item_manager_new (void)
 {
@@ -784,6 +803,8 @@ photos_item_manager_activate_previous_collection (PhotosItemManager *self)
 {
   gpointer *collection;
 
+  g_return_if_fail (PHOTOS_IS_ITEM_MANAGER (self));
+
   photos_item_manager_clear_active_item_load (self);
 
   collection = g_queue_pop_head (self->collection_path);
@@ -885,11 +906,9 @@ photos_item_manager_add_item_for_mode (PhotosItemManager *self, PhotosWindowMode
 void
 photos_item_manager_clear (PhotosItemManager *self, PhotosWindowMode mode)
 {
-  GHashTable *items;
-  GHashTableIter iter;
-  PhotosBaseItem *item;
   PhotosBaseManager *item_mngr_chld;
-  const gchar *id;
+  guint i;
+  guint n_items;
 
   g_return_if_fail (PHOTOS_IS_ITEM_MANAGER (self));
   g_return_if_fail (mode != PHOTOS_WINDOW_MODE_NONE);
@@ -897,20 +916,23 @@ photos_item_manager_clear (PhotosItemManager *self, PhotosWindowMode mode)
   g_return_if_fail (mode != PHOTOS_WINDOW_MODE_PREVIEW);
 
   item_mngr_chld = self->item_mngr_chldrn[mode];
-  items = photos_base_manager_get_objects (item_mngr_chld);
-
-  g_hash_table_iter_init (&iter, items);
-  while (g_hash_table_iter_next (&iter, (gpointer *) &id, (gpointer *) &item))
+  n_items = g_list_model_get_n_items (G_LIST_MODEL (item_mngr_chld));
+  for (i = 0; i < n_items; i++)
     {
+      PhotosBaseItem *item;
       PhotosBaseItem *item1 = NULL;
-      guint i;
+      const gchar *id;
+      guint j;
 
-      for (i = 1; self->item_mngr_chldrn[i] != NULL; i++)
+      item = PHOTOS_BASE_ITEM (g_list_model_get_object (G_LIST_MODEL (item_mngr_chld), i));
+      id = photos_filterable_get_id (PHOTOS_FILTERABLE (item));
+
+      for (j = 1; self->item_mngr_chldrn[j] != NULL; j++)
         {
-          if (item_mngr_chld == self->item_mngr_chldrn[i])
+          if (item_mngr_chld == self->item_mngr_chldrn[j])
             continue;
 
-          item1 = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (self->item_mngr_chldrn[i], id));
+          item1 = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (self->item_mngr_chldrn[j], id));
           if (item1 != NULL)
             break;
         }
@@ -922,6 +944,8 @@ photos_item_manager_clear (PhotosItemManager *self, PhotosWindowMode mode)
 
           photos_base_manager_remove_object_by_id (self->item_mngr_chldrn[0], id);
         }
+
+      g_object_unref (item);
     }
 
   photos_base_manager_clear (item_mngr_chld);
@@ -938,6 +962,9 @@ photos_item_manager_create_item (PhotosItemManager *self, TrackerSparqlCursor *c
   gchar *identifier = NULL;
   gchar **split_identifier = NULL;
 
+  g_return_val_if_fail (PHOTOS_IS_ITEM_MANAGER (self), NULL);
+  g_return_val_if_fail (TRACKER_SPARQL_IS_CURSOR (cursor), NULL);
+
   identifier = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_IDENTIFIER, NULL));
   if (identifier == NULL)
     goto final;
@@ -980,6 +1007,7 @@ photos_item_manager_create_item (PhotosItemManager *self, TrackerSparqlCursor *c
 PhotosBaseItem *
 photos_item_manager_get_active_collection (PhotosItemManager *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_ITEM_MANAGER (self), NULL);
   return self->active_collection;
 }
 
@@ -987,6 +1015,7 @@ photos_item_manager_get_active_collection (PhotosItemManager *self)
 GHashTable *
 photos_item_manager_get_collections (PhotosItemManager *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_ITEM_MANAGER (self), NULL);
   return self->collections;
 }
 
@@ -994,6 +1023,7 @@ photos_item_manager_get_collections (PhotosItemManager *self)
 PhotosBaseManager *
 photos_item_manager_get_for_mode (PhotosItemManager *self, PhotosWindowMode mode)
 {
+  g_return_val_if_fail (PHOTOS_IS_ITEM_MANAGER (self), NULL);
   g_return_val_if_fail (mode != PHOTOS_WINDOW_MODE_NONE, NULL);
   g_return_val_if_fail (mode != PHOTOS_WINDOW_MODE_EDIT, NULL);
   g_return_val_if_fail (mode != PHOTOS_WINDOW_MODE_PREVIEW, NULL);
@@ -1005,6 +1035,7 @@ photos_item_manager_get_for_mode (PhotosItemManager *self, PhotosWindowMode mode
 PhotosLoadState
 photos_item_manager_get_load_state (PhotosItemManager *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_ITEM_MANAGER (self), PHOTOS_LOAD_STATE_NONE);
   return self->load_state;
 }
 
@@ -1089,11 +1120,12 @@ photos_item_manager_wait_for_changes_async (PhotosItemManager *self,
 
   g_return_if_fail (PHOTOS_IS_ITEM_MANAGER (self));
   g_return_if_fail (PHOTOS_IS_BASE_ITEM (item));
+  g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
 
   task = g_task_new (self, cancellable, callback, user_data);
   g_task_set_source_tag (task, photos_item_manager_wait_for_changes_async);
 
-  if (!PHOTOS_IS_LOCAL_ITEM (item) || photos_base_item_is_collection (item))
+  if (!PHOTOS_IS_LOCAL_ITEM (item))
     {
       const gchar *id;
 
@@ -1130,6 +1162,7 @@ photos_item_manager_wait_for_changes_finish (PhotosItemManager *self, GAsyncResu
 gboolean
 photos_mode_controller_get_can_fullscreen (PhotosModeController *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_MODE_CONTROLLER (self), FALSE);
   return self->mode == PHOTOS_WINDOW_MODE_PREVIEW;
 }
 
@@ -1137,6 +1170,7 @@ photos_mode_controller_get_can_fullscreen (PhotosModeController *self)
 gboolean
 photos_mode_controller_get_fullscreen (PhotosModeController *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_MODE_CONTROLLER (self), FALSE);
   return self->fullscreen;
 }
 
@@ -1144,6 +1178,7 @@ photos_mode_controller_get_fullscreen (PhotosModeController *self)
 PhotosWindowMode
 photos_mode_controller_get_window_mode (PhotosModeController *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_MODE_CONTROLLER (self), PHOTOS_WINDOW_MODE_NONE);
   return self->mode;
 }
 
@@ -1154,6 +1189,7 @@ photos_mode_controller_go_back (PhotosModeController *self)
   PhotosWindowMode old_mode;
   PhotosWindowMode tmp;
 
+  g_return_if_fail (PHOTOS_IS_MODE_CONTROLLER (self));
   g_return_if_fail (!g_queue_is_empty (self->history));
 
   old_mode = (PhotosWindowMode) GPOINTER_TO_INT (g_queue_peek_head (self->history));
@@ -1213,6 +1249,7 @@ photos_mode_controller_go_back (PhotosModeController *self)
 void
 photos_mode_controller_toggle_fullscreen (PhotosModeController *self)
 {
+  g_return_if_fail (PHOTOS_IS_MODE_CONTROLLER (self));
   photos_mode_controller_set_fullscreen (self, !self->fullscreen);
 }
 
@@ -1220,6 +1257,8 @@ photos_mode_controller_toggle_fullscreen (PhotosModeController *self)
 void
 photos_mode_controller_set_fullscreen (PhotosModeController *self, gboolean fullscreen)
 {
+  g_return_if_fail (PHOTOS_IS_MODE_CONTROLLER (self));
+
   if (self->fullscreen == fullscreen)
     return;
 
@@ -1234,6 +1273,7 @@ photos_mode_controller_set_window_mode (PhotosModeController *self, PhotosWindow
   PhotosWindowMode old_mode;
   gboolean active_collection_changed = FALSE;
 
+  g_return_if_fail (PHOTOS_IS_MODE_CONTROLLER (self));
   g_return_if_fail (mode != PHOTOS_WINDOW_MODE_NONE);
   g_return_if_fail (mode != PHOTOS_WINDOW_MODE_PREVIEW);
 
