@@ -41,11 +41,6 @@ struct _PhotosLocalItem
   GCancellable *cancellable;
 };
 
-struct _PhotosLocalItemClass
-{
-  PhotosBaseItemClass parent_class;
-};
-
 
 G_DEFINE_TYPE_WITH_CODE (PhotosLocalItem, photos_local_item, PHOTOS_TYPE_BASE_ITEM,
                          photos_utils_ensure_extension_points ();
